jbig2dec

Ralph Giles <[email protected]> Fri, 21 Jun 2002 16:11:32 -0700
Newsgroups gmane.comp.printing.ghostscript.jbig2dec.cvs
Message-ID <[email protected]>
Update of /cvsroot/jbig2dec/jbig2dec
In directory usw-pr-cvs1:/tmp/cvs-serv2245

Modified Files:
	jbig2_symbol_dict.c 
Log Message:
restore original behavior for -DOUTPUT_PBM


Index: jbig2_symbol_dict.c
===================================================================
RCS file: /cvsroot/jbig2dec/jbig2dec/jbig2_symbol_dict.c,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- jbig2_symbol_dict.c	21 Jun 2002 22:56:54 -0000	1.7
+++ jbig2_symbol_dict.c	21 Jun 2002 23:11:29 -0000	1.8
@@ -21,6 +21,11 @@
 #include "jbig2_generic.h"
 #include "jbig2_symbol_dict.h"
 
+#ifdef OUTPUT_PBM
+#include <stdio.h>
+#include "jbig2_image.h"
+#endif
+
 
 /* Table 13 */
 typedef struct {
@@ -145,8 +150,10 @@
 						     as,
 						     image, GB_stats);
 		  /* todo: handle errors */
-		  /* todo: stash gbreg in SDNEWSYMS */
-						     
+		  /* todo: stash image in SDNEWSYMS */
+#ifdef OUTPUT_PBM
+                  jbig2_image_write_pbm(image, stdout);
+#endif
 		}
 	    }